<?php

/**
 * Zone Manager
 *
 * @package zonemanager
 * @version 2.0
 * @author Bonus Themes
 * @copyright Bonus Themes 2008
 * @license GNU/GPL
 * @link http://www.bonusthemes.com/goto/zonemanager
 */

defined('ZONEMANAGER') or die('Direct Access to this location is not allowed.');

define('TPLVAL_SUCCESS' , 0);
define('TPLVAL_NOTEMPLATE' , 1);
define('TPLVAL_INCOMPATIBLE' , 2);
define('TPLVAL_ERRORS' , 3);

function validate_template($base_tpl_dir, $tpl_filename, $manager_version, $min_tpl_version, $max_tpl_version, &$out_error, &$out_name, &$out_url, &$out_gstyles)
{
	$out_error = '';
	$out_name = '';
	$out_url = '';
	$out_gstyles = array();

	// check for a valid template directory

	if ($tpl_filename == '.' || $tpl_filename == '..')
		return TPLVAL_NOTEMPLATE;

	$tpl_dir = $base_tpl_dir . '/' . $tpl_filename;
	if (!is_dir($tpl_dir))
		return TPLVAL_NOTEMPLATE;

	$xml_filename = $tpl_dir . '/templateDetails.xml';
	if (!file_exists($xml_filename))
		return TPLVAL_NOTEMPLATE;


	// read XML file for template general information

	if ($fp = @fopen($xml_filename, 'r')) {
		$content = fread($fp, filesize($xml_filename));
		fclose($fp);

		if (preg_match('~<\s*name\s*>([^<]*)<\s*/\s*name\s*>~i', $content, $m))
			$out_name = trim($m[1]);
		else
			$out_name = '/templates/' . $tpl_filename;

		if (preg_match('~<\s*version\s*>([^<]*)<\s*/\s*version\s*>~i', $content, $m))
			$out_name .= ' v' . trim($m[1]);

		if (preg_match('~<\s*authorUrl\s*>([^<]*)<\s*/\s*authorUrl\s*>~i', $content, $m))
			$out_url = trim($m[1]);
	}
	else {
		$out_error = 'BAD_XML';
		return TPLVAL_ERRORS;
	}

	if ($out_name == '')
		$out_name = '/templates/' . $tpl_filename;


	// check compatibility

	$config_filename = $tpl_dir . '/zl_config.php';
	if (!file_exists($config_filename) || !is_file($config_filename)) {
		$out_error = 'INVALID_ZONECONFIG';
		return TPLVAL_INCOMPATIBLE;
	}

	$info_filename = $tpl_dir . '/zl_info.php';
	if (!file_exists($info_filename) || !is_file($info_filename)) {
		$out_error = 'NO_ZLINFO';
		return TPLVAL_INCOMPATIBLE;
	}

	$styles_filename = $tpl_dir . '/zl_styles.php';
	if (!file_exists($styles_filename) || !is_file($styles_filename)) {
		$out_error = 'INVALID_ZONESTYLES';
		return TPLVAL_INCOMPATIBLE;
	}


	// validate writable files

	if (!is_writable($config_filename)) {
		$out_error = 'NONWRITABLE_ZONECONFIG';
		return TPLVAL_ERRORS;
	}

	if (!is_writable($xml_filename)) {
		$out_error = 'NONWRITABLE_XML';
		return TPLVAL_ERRORS;
	}


	// validate zone layout information file

	require($info_filename);

	if (!isset($tpl_config['layout'])) {
		$out_error = 'MISSING_LAYOUT';
		return TPLVAL_ERRORS;
	}

	if (!isset($tpl_config['reserved_positions'])) {
		$out_error = 'MISSING_RESERVED_POSITIONS';
		return TPLVAL_ERRORS;
	}

	if (!isset($tpl_config['manager_min_ver'])) {
		$out_error = 'MISSING_MANAGER_MIN_VER';
		return TPLVAL_ERRORS;
	}

	if (!isset($tpl_config['zone_tech_ver'])) {
		$out_error = 'MISSING_ZONETECH_VER';
		return TPLVAL_ERRORS;
	}

	$check = version_compare($manager_version, $tpl_config['manager_min_ver']);
	if ($check == -1) {
		$out_error = 'CPANEL_TOO_OLD';
		return TPLVAL_ERRORS;
	}

	$check = version_compare($tpl_config['zone_tech_ver'], $min_tpl_version);
	if ($check == -1) {
		$out_error = 'CPANEL_TOO_NEW';
		return TPLVAL_ERRORS;
	}

	if ($max_tpl_version != '') {
		$check = version_compare($max_tpl_version, $tpl_config['zone_tech_ver']);
		if ($check == -1) {
			$out_error = 'CPANEL_TOO_OLD';
			return TPLVAL_ERRORS;
		}
	}


	// validate and load template styles file

	require($styles_filename);
	$out_gstyles = isset($gstyles) && is_array($gstyles) ? array_keys($gstyles) : array();


	// success

	return TPLVAL_SUCCESS;
}

?>